!=================================================================
!
! NAME: 
!
!    Constants
!
! FUNCTION:
!
!    Constants used by the code
!
! TYPE/LANGUAGE: 
!
!    F90 module
!
! DESCRIPTION:  
!
!    Contains the constants used by the code
!
! ROUTINES TO BE USED EXTERNALLY:
!
! ROUTINES USED INTERNALLY:
!
! HISTORY:
! 
!   Original version by Jonathan P.D. Mittaz on 9/18/2013
!
!=================================================================
MODULE Constants

  USE Kinds
  
  IMPLICIT NONE

  CHARACTER(LEN=25), PARAMETER :: Code_Version='DW Model Version 1.0'

  REAL(RealType), PARAMETER :: pi = 3.1415926535897932_RealType
  REAL(RealType), PARAMETER :: d2r = pi/180.0_RealType
  REAL(RealType), PARAMETER :: r2d = 1.0_RealType/d2r

  REAL(RealType), PARAMETER :: min_solar = 5._RealType
  REAL(RealType), PARAMETER :: solar_constant = 1366._RealType
  REAL(RealType), PARAMETER :: s1 = -105_RealType
  REAL(RealType), PARAMETER :: s2 = 596.2_RealType
  REAL(RealType), PARAMETER :: s3 = 4.3_RealType
  REAL(RealType), PARAMETER :: s4 = -12.7_RealType

  REAL(RealType), PARAMETER :: c1 = -429.3_RealType
  REAL(RealType), PARAMETER :: c2 = -2.1_RealType
  REAL(RealType), PARAMETER :: c3 = 19.3_RealType

  REAL(RealType), PARAMETER :: w0aer = 0.0_RealType
  REAL(RealType), PARAMETER :: fc = 0.84_RealType
  REAL(RealType), PARAMETER :: ag = 0.2_RealType

  REAL(RealType), PARAMETER :: grav = 9.80665_RealType
  REAL(RealType), PARAMETER :: rho_atmos = 1.225_RealType
  REAL(RealType), PARAMETER :: rho_ocean = 1027.0_RealType
  REAL(RealType), PARAMETER :: sqrt_cd = 0.03873_RealType   ! sqrt(0.0015)
  REAL(RealType), PARAMETER :: sqrt_rho_air_sea = SQRT(rho_atmos/rho_ocean)

  REAL(RealType), PARAMETER :: Umol = 8.8E-7_RealType
  REAL(RealType), PARAMETER :: Kappa = 0.40_RealType
  REAL(RealType), PARAMETER :: SQ = 0.41_RealType
  REAL(RealType), PARAMETER :: EPS = 1.e-10_RealType
  REAL(RealType), PARAMETER :: SMALL = 1.e-10_RealType

  !
  ! Note these two are constants defined in Kantha & Clayson 1994 and are 
  ! not directly associated with a single physical parameter
  !
  REAL(RealType), PARAMETER :: BEE = Kappa/1.81_RealType
  REAL(RealType), PARAMETER :: EMM = 1.0_RealType

  REAL(RealType), PARAMETER :: convert_to_K = 273.16_RealType

END MODULE Constants
